import { z } from 'zod';
/**
 * Contact Object
 *
 * Contact information for the exposed API.
 *
 * @see https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.1.md#contact-object
 */
export declare const ContactObjectSchema: z.ZodObject<{
    /** The identifying name of the contact person/organization. */
    name: z.ZodOptional<z.ZodString>;
    /** The URL pointing to the contact information. This MUST be in the form of a URL. */
    url: z.ZodCatch<z.ZodOptional<z.ZodString>>;
    /** The email address of the contact person/organization. This MUST be in the form of an email address. */
    email: z.ZodCatch<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    url?: string | undefined;
    name?: string | undefined;
    email?: string | undefined;
}, {
    url?: unknown;
    name?: string | undefined;
    email?: unknown;
}>;
//# sourceMappingURL=contact-object.d.ts.map