import { z } from 'zod';
import { CallbackObjectSchema } from './callback-object.js';
import { ReferenceObjectSchema } from './reference-object.js';
/**
 * Components Object
 *
 * Holds a set of reusable objects for different aspects of the OAS. All objects defined within the Components Object
 * will have no effect on the API unless they are explicitly referenced from outside the Components Object.
 *
 * @see https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.1.md#components-object
 */
export declare const ComponentsObjectSchema: z.ZodObject<z.objectUtil.extendShape<{
    schemas: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>>;
    responses: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        description: z.ZodString;
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            description: z.ZodOptional<z.ZodString>;
            required: z.ZodOptional<z.ZodBoolean>;
            deprecated: z.ZodOptional<z.ZodBoolean>;
            style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
            explode: z.ZodOptional<z.ZodBoolean>;
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>>;
        links: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            operationRef: z.ZodOptional<z.ZodString>;
            operationId: z.ZodOptional<z.ZodString>;
            parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodString, string, string>>>;
            requestBody: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            description: z.ZodOptional<z.ZodString>;
            server: z.ZodOptional<z.ZodObject<{
                url: z.ZodString;
                description: z.ZodOptional<z.ZodString>;
                variables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    enum: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    default: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            }, {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        description: string;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        headers?: Record<string, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }> | undefined;
        links?: Record<string, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }> | undefined;
    }, {
        description: string;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        headers?: Record<string, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }> | undefined;
        links?: Record<string, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }> | undefined;
    }>>>;
    parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        name: z.ZodString;
        in: z.ZodEnum<["query", "header", "path", "cookie"]>;
        description: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodBoolean>;
        deprecated: z.ZodOptional<z.ZodBoolean>;
        allowEmptyValue: z.ZodOptional<z.ZodBoolean>;
        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "form", "simple", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
        explode: z.ZodOptional<z.ZodBoolean>;
        allowReserved: z.ZodOptional<z.ZodBoolean>;
        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
        example: z.ZodOptional<z.ZodAny>;
        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            value: z.ZodOptional<z.ZodAny>;
            externalValue: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        in: "path" | "query" | "header" | "cookie";
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
        allowEmptyValue?: boolean | undefined;
        allowReserved?: boolean | undefined;
    }, {
        name: string;
        in: "path" | "query" | "header" | "cookie";
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
        allowEmptyValue?: boolean | undefined;
        allowReserved?: boolean | undefined;
    }>>>;
    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        value: z.ZodOptional<z.ZodAny>;
        externalValue: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        summary?: string | undefined;
        value?: any;
        externalValue?: string | undefined;
    }, {
        description?: string | undefined;
        summary?: string | undefined;
        value?: any;
        externalValue?: string | undefined;
    }>>>;
    requestBodies: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        description: z.ZodOptional<z.ZodString>;
        content: z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>;
        required: z.ZodOptional<z.ZodBoolean>;
        encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            contentType: z.ZodString;
            headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                description: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodBoolean>;
                deprecated: z.ZodOptional<z.ZodBoolean>;
                style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                explode: z.ZodOptional<z.ZodBoolean>;
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
                content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        content: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>;
        description?: string | undefined;
        required?: boolean | undefined;
        encoding?: Record<string, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }> | undefined;
    }, {
        content: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>;
        description?: string | undefined;
        required?: boolean | undefined;
        encoding?: Record<string, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }> | undefined;
    }>>>;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        description: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodBoolean>;
        deprecated: z.ZodOptional<z.ZodBoolean>;
        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
        explode: z.ZodOptional<z.ZodBoolean>;
        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
        example: z.ZodOptional<z.ZodAny>;
        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            value: z.ZodOptional<z.ZodAny>;
            externalValue: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
    }, {
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
    }>>>;
    securitySchemes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"apiKey">;
        name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        in: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodEnum<["query", "header", "cookie"]>>>>;
    }>, "strip", z.ZodTypeAny, {
        name: string;
        in: "query" | "header" | "cookie";
        type: "apiKey";
        description?: string | undefined;
    }, {
        type: "apiKey";
        description?: string | undefined;
        name?: string | undefined;
        in?: unknown;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"http">;
        scheme: z.ZodDefault<z.ZodOptional<z.ZodPipeline<z.ZodString, z.ZodEnum<["basic", "bearer"]>>>>;
        bearerFormat: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"JWT">, z.ZodLiteral<"bearer">, z.ZodString]>>;
    }>, "strip", z.ZodTypeAny, {
        type: "http";
        scheme: "basic" | "bearer";
        description?: string | undefined;
        bearerFormat?: string | undefined;
    }, {
        type: "http";
        description?: string | undefined;
        scheme?: string | undefined;
        bearerFormat?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"mutualTLS">;
    }>, "strip", z.ZodTypeAny, {
        type: "mutualTLS";
        description?: string | undefined;
    }, {
        type: "mutualTLS";
        description?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"oauth2">;
        flows: z.ZodObject<{
            implicit: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"implicit">>;
                authorizationUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
            }>>>;
            password: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"password">>;
                tokenUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            }>>>;
            clientCredentials: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"clientCredentials">>;
                tokenUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            }>>>;
            authorizationCode: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"authorizationCode">>;
                authorizationUrl: z.ZodDefault<z.ZodString>;
                tokenUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                tokenUrl: string;
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
                tokenUrl?: string | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            implicit?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            password?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                tokenUrl: string;
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
        }, {
            implicit?: {
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
            } | undefined;
            password?: {
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
                tokenUrl?: string | undefined;
            } | undefined;
        }>;
    }>, "strip", z.ZodTypeAny, {
        type: "oauth2";
        flows: {
            implicit?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            password?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                tokenUrl: string;
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
        };
        description?: string | undefined;
    }, {
        type: "oauth2";
        flows: {
            implicit?: {
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
            } | undefined;
            password?: {
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
                tokenUrl?: string | undefined;
            } | undefined;
        };
        description?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"openIdConnect">;
        openIdConnectUrl: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        type: "openIdConnect";
        openIdConnectUrl: string;
        description?: string | undefined;
    }, {
        type: "openIdConnect";
        description?: string | undefined;
        openIdConnectUrl?: string | undefined;
    }>]>>>;
    links: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        operationRef: z.ZodOptional<z.ZodString>;
        operationId: z.ZodOptional<z.ZodString>;
        parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodString, string, string>>>;
        requestBody: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
        description: z.ZodOptional<z.ZodString>;
        server: z.ZodOptional<z.ZodObject<{
            url: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            variables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                enum: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                default: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        operationId?: string | undefined;
        parameters?: Record<string, string> | undefined;
        requestBody?: string | undefined;
        operationRef?: string | undefined;
        server?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        } | undefined;
    }, {
        description?: string | undefined;
        operationId?: string | undefined;
        parameters?: Record<string, string> | undefined;
        requestBody?: string | undefined;
        operationRef?: string | undefined;
        server?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        } | undefined;
    }>>>;
    callbacks: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodEffects<z.ZodString, string, string>, z.ZodType<{
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
    } & {
        get?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        put?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        post?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        delete?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        options?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        head?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        patch?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        trace?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
    }, z.ZodTypeDef, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
    } & {
        get?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        put?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        post?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        delete?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        options?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        head?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        patch?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        trace?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
    }>>>>;
    pathItems: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<{
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        servers: z.ZodOptional<z.ZodArray<z.ZodObject<{
            url: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            variables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                enum: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                default: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }>, "many">>;
        parameters: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            in: z.ZodEnum<["query", "header", "path", "cookie"]>;
            description: z.ZodOptional<z.ZodString>;
            required: z.ZodOptional<z.ZodBoolean>;
            deprecated: z.ZodOptional<z.ZodBoolean>;
            allowEmptyValue: z.ZodOptional<z.ZodBoolean>;
            style: z.ZodOptional<z.ZodEnum<["matrix", "label", "form", "simple", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
            explode: z.ZodOptional<z.ZodBoolean>;
            allowReserved: z.ZodOptional<z.ZodBoolean>;
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
                encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    contentType: z.ZodString;
                    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        description: z.ZodOptional<z.ZodString>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        deprecated: z.ZodOptional<z.ZodBoolean>;
                        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                        explode: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                            example: z.ZodOptional<z.ZodAny>;
                            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                                summary: z.ZodOptional<z.ZodString>;
                                description: z.ZodOptional<z.ZodString>;
                                value: z.ZodOptional<z.ZodAny>;
                                externalValue: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }>>>;
                        }, "strip", z.ZodTypeAny, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }, {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }>, "many">>;
    }, {
        get: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
        put: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
        post: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
        delete: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
        options: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
        head: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
        patch: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
        trace: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }>>;
    }>, "strip", z.ZodTypeAny, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
        get?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        put?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        post?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        delete?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        options?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        head?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        patch?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        trace?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
    }, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
        get?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        put?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        post?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        delete?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        options?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        head?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        patch?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
        trace?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            }[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof import("../processed/index.js").CallbackObjectSchema>>;
        }) | undefined;
    }>>>;
}, {
    /**
     * An object to hold reusable Schema Objects.
     */
    schemas: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodType<any, z.ZodTypeDef, any>>>;
    /**
     * An object to hold reusable Response Objects.
     */
    responses: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodString;
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            description: z.ZodOptional<z.ZodString>;
            required: z.ZodOptional<z.ZodBoolean>;
            deprecated: z.ZodOptional<z.ZodBoolean>;
            style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
            explode: z.ZodOptional<z.ZodBoolean>;
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>>;
        links: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            operationRef: z.ZodOptional<z.ZodString>;
            operationId: z.ZodOptional<z.ZodString>;
            parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodString, string, string>>>;
            requestBody: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            description: z.ZodOptional<z.ZodString>;
            server: z.ZodOptional<z.ZodObject<{
                url: z.ZodString;
                description: z.ZodOptional<z.ZodString>;
                variables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    enum: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    default: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            }, {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }>>>;
    }, {
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
            $ref: z.ZodString;
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            description: z.ZodOptional<z.ZodString>;
            required: z.ZodOptional<z.ZodBoolean>;
            deprecated: z.ZodOptional<z.ZodBoolean>;
            style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
            explode: z.ZodOptional<z.ZodBoolean>;
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }>>>;
        }, {
            schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                $ref: z.ZodString;
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }>, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>]>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }>>>;
        }>, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }, {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }>]>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, {
            schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                $ref: z.ZodString;
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }>, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>]>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, {
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                    $ref: z.ZodString;
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, {
                    schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                        $ref: z.ZodString;
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }>, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>]>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }>, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>]>>>;
            }>, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }>, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>>;
        links: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
            $ref: z.ZodString;
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }>, z.ZodObject<{
            operationRef: z.ZodOptional<z.ZodString>;
            operationId: z.ZodOptional<z.ZodString>;
            parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodString, string, string>>>;
            requestBody: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            description: z.ZodOptional<z.ZodString>;
            server: z.ZodOptional<z.ZodObject<{
                url: z.ZodString;
                description: z.ZodOptional<z.ZodString>;
                variables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    enum: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    default: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            }, {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        }>]>>>;
    }>, "strip", z.ZodTypeAny, {
        description: string;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        headers?: Record<string, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }> | undefined;
        links?: Record<string, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
    }, {
        description: string;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        headers?: Record<string, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }> | undefined;
        links?: Record<string, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
    }>]>>>;
    /**
     * An object to hold reusable Parameter Objects.
     */
    parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        name: z.ZodString;
        in: z.ZodEnum<["query", "header", "path", "cookie"]>;
        description: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodBoolean>;
        deprecated: z.ZodOptional<z.ZodBoolean>;
        allowEmptyValue: z.ZodOptional<z.ZodBoolean>;
        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "form", "simple", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
        explode: z.ZodOptional<z.ZodBoolean>;
        allowReserved: z.ZodOptional<z.ZodBoolean>;
        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
        example: z.ZodOptional<z.ZodAny>;
        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            value: z.ZodOptional<z.ZodAny>;
            externalValue: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>>;
    }, {
        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
            $ref: z.ZodString;
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }>, z.ZodObject<{
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            value: z.ZodOptional<z.ZodAny>;
            externalValue: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }>]>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, {
            schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                $ref: z.ZodString;
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }>, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>]>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, {
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                    $ref: z.ZodString;
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }>, z.ZodObject<z.objectUtil.extendShape<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, {
                    schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                        $ref: z.ZodString;
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }>, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>]>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }>, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>]>>>;
            }>, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }>, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>>;
    }>, "strip", z.ZodTypeAny, {
        name: string;
        in: "path" | "query" | "header" | "cookie";
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
        allowEmptyValue?: boolean | undefined;
        allowReserved?: boolean | undefined;
    }, {
        name: string;
        in: "path" | "query" | "header" | "cookie";
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
        allowEmptyValue?: boolean | undefined;
        allowReserved?: boolean | undefined;
    }>]>>>;
    /**
     * An object to hold reusable Example Objects.
     */
    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodObject<{
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        value: z.ZodOptional<z.ZodAny>;
        externalValue: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        summary?: string | undefined;
        value?: any;
        externalValue?: string | undefined;
    }, {
        description?: string | undefined;
        summary?: string | undefined;
        value?: any;
        externalValue?: string | undefined;
    }>]>>>;
    /**
     * An object to hold reusable Request Body Objects.
     */
    requestBodies: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodObject<{
        description: z.ZodOptional<z.ZodString>;
        content: z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                contentType: z.ZodString;
                headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    description: z.ZodOptional<z.ZodString>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    deprecated: z.ZodOptional<z.ZodBoolean>;
                    style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                    explode: z.ZodOptional<z.ZodBoolean>;
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                    content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>>;
        required: z.ZodOptional<z.ZodBoolean>;
        encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            contentType: z.ZodString;
            headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                description: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodBoolean>;
                deprecated: z.ZodOptional<z.ZodBoolean>;
                style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                explode: z.ZodOptional<z.ZodBoolean>;
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
                content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                    example: z.ZodOptional<z.ZodAny>;
                    examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        value: z.ZodOptional<z.ZodAny>;
                        externalValue: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        content: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>;
        description?: string | undefined;
        required?: boolean | undefined;
        encoding?: Record<string, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }> | undefined;
    }, {
        content: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>;
        description?: string | undefined;
        required?: boolean | undefined;
        encoding?: Record<string, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }> | undefined;
    }>]>>>;
    /**
     * An object to hold reusable Header Objects.
     */
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodBoolean>;
        deprecated: z.ZodOptional<z.ZodBoolean>;
        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
        explode: z.ZodOptional<z.ZodBoolean>;
        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
        example: z.ZodOptional<z.ZodAny>;
        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            value: z.ZodOptional<z.ZodAny>;
            externalValue: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }>>>;
    }, {
        schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
            $ref: z.ZodString;
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }>, z.ZodObject<{
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            value: z.ZodOptional<z.ZodAny>;
            externalValue: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        }>]>>>;
        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }>>>;
    }>, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: any;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
    }, {
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: any;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
    }>]>>>;
    /**
     * An object to hold reusable Security Scheme Objects.
     */
    securitySchemes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodUnion<[z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"apiKey">;
        name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        in: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodEnum<["query", "header", "cookie"]>>>>;
    }>, "strip", z.ZodTypeAny, {
        name: string;
        in: "query" | "header" | "cookie";
        type: "apiKey";
        description?: string | undefined;
    }, {
        type: "apiKey";
        description?: string | undefined;
        name?: string | undefined;
        in?: unknown;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"http">;
        scheme: z.ZodDefault<z.ZodOptional<z.ZodPipeline<z.ZodString, z.ZodEnum<["basic", "bearer"]>>>>;
        bearerFormat: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"JWT">, z.ZodLiteral<"bearer">, z.ZodString]>>;
    }>, "strip", z.ZodTypeAny, {
        type: "http";
        scheme: "basic" | "bearer";
        description?: string | undefined;
        bearerFormat?: string | undefined;
    }, {
        type: "http";
        description?: string | undefined;
        scheme?: string | undefined;
        bearerFormat?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"mutualTLS">;
    }>, "strip", z.ZodTypeAny, {
        type: "mutualTLS";
        description?: string | undefined;
    }, {
        type: "mutualTLS";
        description?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"oauth2">;
        flows: z.ZodObject<{
            implicit: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"implicit">>;
                authorizationUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
            }>>>;
            password: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"password">>;
                tokenUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            }>>>;
            clientCredentials: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"clientCredentials">>;
                tokenUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            }>>>;
            authorizationCode: z.ZodOptional<z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                refreshUrl: z.ZodOptional<z.ZodString>;
                scopes: z.ZodCatch<z.ZodDefault<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodOptional<z.ZodString>>>>>;
            }, {
                type: z.ZodOptional<z.ZodLiteral<"authorizationCode">>;
                authorizationUrl: z.ZodDefault<z.ZodString>;
                tokenUrl: z.ZodDefault<z.ZodString>;
            }>, "strip", z.ZodTypeAny, {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                tokenUrl: string;
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
            }, {
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
                tokenUrl?: string | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            implicit?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            password?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                tokenUrl: string;
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
        }, {
            implicit?: {
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
            } | undefined;
            password?: {
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
                tokenUrl?: string | undefined;
            } | undefined;
        }>;
    }>, "strip", z.ZodTypeAny, {
        type: "oauth2";
        flows: {
            implicit?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            password?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                tokenUrl: string;
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
        };
        description?: string | undefined;
    }, {
        type: "oauth2";
        flows: {
            implicit?: {
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
            } | undefined;
            password?: {
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
                tokenUrl?: string | undefined;
            } | undefined;
        };
        description?: string | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        description: z.ZodOptional<z.ZodString>;
    }, {
        type: z.ZodLiteral<"openIdConnect">;
        openIdConnectUrl: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        type: "openIdConnect";
        openIdConnectUrl: string;
        description?: string | undefined;
    }, {
        type: "openIdConnect";
        description?: string | undefined;
        openIdConnectUrl?: string | undefined;
    }>]>]>>>;
    /**
     * An object to hold reusable Link Objects.
     */
    links: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodObject<{
        operationRef: z.ZodOptional<z.ZodString>;
        operationId: z.ZodOptional<z.ZodString>;
        parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodString, string, string>>>;
        requestBody: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
        description: z.ZodOptional<z.ZodString>;
        server: z.ZodOptional<z.ZodObject<{
            url: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            variables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                enum: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                default: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        description?: string | undefined;
        operationId?: string | undefined;
        parameters?: Record<string, string> | undefined;
        requestBody?: string | undefined;
        operationRef?: string | undefined;
        server?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        } | undefined;
    }, {
        description?: string | undefined;
        operationId?: string | undefined;
        parameters?: Record<string, string> | undefined;
        requestBody?: string | undefined;
        operationRef?: string | undefined;
        server?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        } | undefined;
    }>]>>>;
    /**
     * An object to hold reusable Callback Objects.
     */
    callbacks: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
        $ref: z.ZodString;
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }>, z.ZodRecord<z.ZodEffects<z.ZodString, string, string>, z.ZodType<{
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
    } & {
        get?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        put?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        post?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        delete?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        options?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        head?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        patch?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        trace?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
    }, z.ZodTypeDef, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
    } & {
        get?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        put?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        post?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        delete?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        options?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        head?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        patch?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        trace?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
    }>>]>>>;
    /**
     * An object to hold reusable Path Item Objects.
     */
    pathItems: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        summary: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        servers: z.ZodOptional<z.ZodArray<z.ZodObject<{
            url: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            variables: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                enum: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                default: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }, {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }>, "many">>;
        parameters: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            in: z.ZodEnum<["query", "header", "path", "cookie"]>;
            description: z.ZodOptional<z.ZodString>;
            required: z.ZodOptional<z.ZodBoolean>;
            deprecated: z.ZodOptional<z.ZodBoolean>;
            allowEmptyValue: z.ZodOptional<z.ZodBoolean>;
            style: z.ZodOptional<z.ZodEnum<["matrix", "label", "form", "simple", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
            explode: z.ZodOptional<z.ZodBoolean>;
            allowReserved: z.ZodOptional<z.ZodBoolean>;
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
                encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    contentType: z.ZodString;
                    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        description: z.ZodOptional<z.ZodString>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        deprecated: z.ZodOptional<z.ZodBoolean>;
                        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                        explode: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                            example: z.ZodOptional<z.ZodAny>;
                            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                                summary: z.ZodOptional<z.ZodString>;
                                description: z.ZodOptional<z.ZodString>;
                                value: z.ZodOptional<z.ZodAny>;
                                externalValue: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }>>>;
                        }, "strip", z.ZodTypeAny, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }, {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }>, "many">>;
    }, {
        parameters: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            $ref: z.ZodString;
            summary: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }>, z.ZodObject<z.objectUtil.extendShape<{
            name: z.ZodString;
            in: z.ZodEnum<["query", "header", "path", "cookie"]>;
            description: z.ZodOptional<z.ZodString>;
            required: z.ZodOptional<z.ZodBoolean>;
            deprecated: z.ZodOptional<z.ZodBoolean>;
            allowEmptyValue: z.ZodOptional<z.ZodBoolean>;
            style: z.ZodOptional<z.ZodEnum<["matrix", "label", "form", "simple", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
            explode: z.ZodOptional<z.ZodBoolean>;
            allowReserved: z.ZodOptional<z.ZodBoolean>;
            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
            example: z.ZodOptional<z.ZodAny>;
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
                encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    contentType: z.ZodString;
                    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        description: z.ZodOptional<z.ZodString>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        deprecated: z.ZodOptional<z.ZodBoolean>;
                        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                        explode: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                            example: z.ZodOptional<z.ZodAny>;
                            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                                summary: z.ZodOptional<z.ZodString>;
                                description: z.ZodOptional<z.ZodString>;
                                value: z.ZodOptional<z.ZodAny>;
                                externalValue: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }>>>;
                        }, "strip", z.ZodTypeAny, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }>>>;
        }, {
            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                $ref: z.ZodString;
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }, {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }>, z.ZodObject<{
                summary: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodAny>;
                externalValue: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }>]>>>;
            content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<{
                schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>>>;
                encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                    contentType: z.ZodString;
                    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        description: z.ZodOptional<z.ZodString>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        deprecated: z.ZodOptional<z.ZodBoolean>;
                        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                        explode: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                            example: z.ZodOptional<z.ZodAny>;
                            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                                summary: z.ZodOptional<z.ZodString>;
                                description: z.ZodOptional<z.ZodString>;
                                value: z.ZodOptional<z.ZodAny>;
                                externalValue: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }>>>;
                        }, "strip", z.ZodTypeAny, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }>>>;
            }, {
                schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
                example: z.ZodOptional<z.ZodAny>;
                examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                    $ref: z.ZodString;
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }>, z.ZodObject<{
                    summary: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodAny>;
                    externalValue: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }>]>>>;
                encoding: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.objectUtil.extendShape<{
                    contentType: z.ZodString;
                    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                        description: z.ZodOptional<z.ZodString>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        deprecated: z.ZodOptional<z.ZodBoolean>;
                        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                        explode: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                            example: z.ZodOptional<z.ZodAny>;
                            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                                summary: z.ZodOptional<z.ZodString>;
                                description: z.ZodOptional<z.ZodString>;
                                value: z.ZodOptional<z.ZodAny>;
                                externalValue: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }>>>;
                        }, "strip", z.ZodTypeAny, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }>>>;
                }, {
                    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                        $ref: z.ZodString;
                        summary: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }>, z.ZodObject<z.objectUtil.extendShape<{
                        description: z.ZodOptional<z.ZodString>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        deprecated: z.ZodOptional<z.ZodBoolean>;
                        style: z.ZodOptional<z.ZodEnum<["matrix", "label", "simple", "form", "spaceDelimited", "pipeDelimited", "deepObject"]>>;
                        explode: z.ZodOptional<z.ZodBoolean>;
                        schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                        example: z.ZodOptional<z.ZodAny>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>>>;
                        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                            example: z.ZodOptional<z.ZodAny>;
                            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                                summary: z.ZodOptional<z.ZodString>;
                                description: z.ZodOptional<z.ZodString>;
                                value: z.ZodOptional<z.ZodAny>;
                                externalValue: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }>>>;
                        }, "strip", z.ZodTypeAny, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }>>>;
                    }, {
                        schema: z.ZodOptional<z.ZodType<any, z.ZodTypeDef, any>>;
                        examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodObject<{
                            $ref: z.ZodString;
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }>, z.ZodObject<{
                            summary: z.ZodOptional<z.ZodString>;
                            description: z.ZodOptional<z.ZodString>;
                            value: z.ZodOptional<z.ZodAny>;
                            externalValue: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }>]>>>;
                        content: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                            schema: z.ZodOptional<z.ZodType<Record<string, any>, z.ZodTypeDef, Record<string, any>>>;
                            example: z.ZodOptional<z.ZodAny>;
                            examples: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                                summary: z.ZodOptional<z.ZodString>;
                                description: z.ZodOptional<z.ZodString>;
                                value: z.ZodOptional<z.ZodAny>;
                                externalValue: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }>>>;
                        }, "strip", z.ZodTypeAny, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }>>>;
                    }>, "strip", z.ZodTypeAny, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }>]>>>;
                }>, "strip", z.ZodTypeAny, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }>>>;
            }>, "strip", z.ZodTypeAny, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }>>>;
        }>, "strip", z.ZodTypeAny, {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }, {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }>]>, "many">>;
    }>, {
        $ref: z.ZodOptional<z.ZodString>;
        get: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
        put: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
        post: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
        delete: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
        options: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
        head: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
        patch: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
        trace: z.ZodOptional<z.ZodType<{
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }, z.ZodTypeDef, {
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }>>;
    }>, "strip", z.ZodTypeAny, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: ({
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        })[] | undefined;
        $ref?: string | undefined;
        get?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        put?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        post?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        delete?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        options?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        head?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        patch?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        trace?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
    }, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: ({
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        })[] | undefined;
        $ref?: string | undefined;
        get?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        put?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        post?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        delete?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        options?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        head?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        patch?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        trace?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
    }>>>;
}>, "strip", z.ZodTypeAny, {
    parameters?: Record<string, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    } | {
        name: string;
        in: "path" | "query" | "header" | "cookie";
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
        allowEmptyValue?: boolean | undefined;
        allowReserved?: boolean | undefined;
    }> | undefined;
    responses?: Record<string, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    } | {
        description: string;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        headers?: Record<string, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }> | undefined;
        links?: Record<string, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
    }> | undefined;
    callbacks?: Record<string, Record<string, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
    } & {
        get?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        put?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        post?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        delete?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        options?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        head?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        patch?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        trace?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
    }> | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    headers?: Record<string, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    } | {
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: any;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
    }> | undefined;
    links?: Record<string, {
        description?: string | undefined;
        operationId?: string | undefined;
        parameters?: Record<string, string> | undefined;
        requestBody?: string | undefined;
        operationRef?: string | undefined;
        server?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        } | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    examples?: Record<string, {
        description?: string | undefined;
        summary?: string | undefined;
        value?: any;
        externalValue?: string | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    schemas?: Record<string, any> | undefined;
    requestBodies?: Record<string, {
        content: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>;
        description?: string | undefined;
        required?: boolean | undefined;
        encoding?: Record<string, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }> | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    securitySchemes?: Record<string, {
        name: string;
        in: "query" | "header" | "cookie";
        type: "apiKey";
        description?: string | undefined;
    } | {
        type: "http";
        scheme: "basic" | "bearer";
        description?: string | undefined;
        bearerFormat?: string | undefined;
    } | {
        type: "openIdConnect";
        openIdConnectUrl: string;
        description?: string | undefined;
    } | {
        type: "oauth2";
        flows: {
            implicit?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            password?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                scopes: Record<string, string | undefined>;
                tokenUrl: string;
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                scopes: Record<string, string | undefined>;
                authorizationUrl: string;
                tokenUrl: string;
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
            } | undefined;
        };
        description?: string | undefined;
    } | {
        type: "mutualTLS";
        description?: string | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    pathItems?: Record<string, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: ({
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        })[] | undefined;
        $ref?: string | undefined;
        get?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        put?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        post?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        delete?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        options?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        head?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        patch?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        trace?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
    }> | undefined;
}, {
    parameters?: Record<string, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    } | {
        name: string;
        in: "path" | "query" | "header" | "cookie";
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: Record<string, any> | undefined;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
        allowEmptyValue?: boolean | undefined;
        allowReserved?: boolean | undefined;
    }> | undefined;
    responses?: Record<string, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    } | {
        description: string;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                } | {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }> | undefined;
        headers?: Record<string, {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: any;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
        }> | undefined;
        links?: Record<string, {
            description?: string | undefined;
            operationId?: string | undefined;
            parameters?: Record<string, string> | undefined;
            requestBody?: string | undefined;
            operationRef?: string | undefined;
            server?: {
                url: string;
                description?: string | undefined;
                variables?: Record<string, {
                    description?: string | undefined;
                    default?: string | undefined;
                    enum?: string[] | undefined;
                }> | undefined;
            } | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
    }> | undefined;
    callbacks?: Record<string, Record<string, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        }[] | undefined;
    } & {
        get?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        put?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        post?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        delete?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        options?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        head?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        patch?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
        trace?: z.infer<typeof import("../processed/operation-object-without-callbacks.js").OperationObjectSchemaWithoutCallbacks>;
    }> | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    headers?: Record<string, {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    } | {
        description?: string | undefined;
        deprecated?: boolean | undefined;
        content?: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
        }> | undefined;
        required?: boolean | undefined;
        example?: any;
        examples?: Record<string, {
            description?: string | undefined;
            summary?: string | undefined;
            value?: any;
            externalValue?: string | undefined;
        } | {
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        }> | undefined;
        schema?: any;
        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
        explode?: boolean | undefined;
    }> | undefined;
    links?: Record<string, {
        description?: string | undefined;
        operationId?: string | undefined;
        parameters?: Record<string, string> | undefined;
        requestBody?: string | undefined;
        operationRef?: string | undefined;
        server?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        } | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    examples?: Record<string, {
        description?: string | undefined;
        summary?: string | undefined;
        value?: any;
        externalValue?: string | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    schemas?: Record<string, any> | undefined;
    requestBodies?: Record<string, {
        content: Record<string, {
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            encoding?: Record<string, {
                contentType: string;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
            }> | undefined;
        }>;
        description?: string | undefined;
        required?: boolean | undefined;
        encoding?: Record<string, {
            contentType: string;
            headers?: Record<string, {
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
            }> | undefined;
        }> | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    securitySchemes?: Record<string, {
        type: "apiKey";
        description?: string | undefined;
        name?: string | undefined;
        in?: unknown;
    } | {
        type: "http";
        description?: string | undefined;
        scheme?: string | undefined;
        bearerFormat?: string | undefined;
    } | {
        type: "openIdConnect";
        description?: string | undefined;
        openIdConnectUrl?: string | undefined;
    } | {
        type: "oauth2";
        flows: {
            implicit?: {
                type?: "implicit" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
            } | undefined;
            password?: {
                type?: "password" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            clientCredentials?: {
                type?: "clientCredentials" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                tokenUrl?: string | undefined;
            } | undefined;
            authorizationCode?: {
                type?: "authorizationCode" | undefined;
                refreshUrl?: string | undefined;
                scopes?: unknown;
                authorizationUrl?: string | undefined;
                tokenUrl?: string | undefined;
            } | undefined;
        };
        description?: string | undefined;
    } | {
        type: "mutualTLS";
        description?: string | undefined;
    } | {
        $ref: string;
        description?: string | undefined;
        summary?: string | undefined;
    }> | undefined;
    pathItems?: Record<string, {
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: Record<string, {
                description?: string | undefined;
                default?: string | undefined;
                enum?: string[] | undefined;
            }> | undefined;
        }[] | undefined;
        description?: string | undefined;
        summary?: string | undefined;
        parameters?: ({
            $ref: string;
            description?: string | undefined;
            summary?: string | undefined;
        } | {
            name: string;
            in: "path" | "query" | "header" | "cookie";
            description?: string | undefined;
            deprecated?: boolean | undefined;
            content?: Record<string, {
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: any;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    } | {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        } | {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        }> | undefined;
                        schema?: any;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            }> | undefined;
            required?: boolean | undefined;
            example?: any;
            examples?: Record<string, {
                description?: string | undefined;
                summary?: string | undefined;
                value?: any;
                externalValue?: string | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            }> | undefined;
            schema?: Record<string, any> | undefined;
            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
            explode?: boolean | undefined;
            allowEmptyValue?: boolean | undefined;
            allowReserved?: boolean | undefined;
        })[] | undefined;
        $ref?: string | undefined;
        get?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        put?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        post?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        delete?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        options?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        head?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        patch?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
        trace?: ({
            security?: Record<string, string[]>[] | undefined;
            tags?: string[] | undefined;
            externalDocs?: {
                url: string;
                description?: string | undefined;
            } | undefined;
            description?: string | undefined;
            summary?: string | undefined;
            operationId?: string | undefined;
            parameters?: ({
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | {
                name: string;
                in: "path" | "query" | "header" | "cookie";
                description?: string | undefined;
                deprecated?: boolean | undefined;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    } | {
                        $ref: string;
                        description?: string | undefined;
                        summary?: string | undefined;
                    }> | undefined;
                    schema?: any;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            $ref: string;
                            description?: string | undefined;
                            summary?: string | undefined;
                        } | {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            } | {
                                $ref: string;
                                description?: string | undefined;
                                summary?: string | undefined;
                            }> | undefined;
                            schema?: any;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                required?: boolean | undefined;
                example?: any;
                examples?: Record<string, {
                    description?: string | undefined;
                    summary?: string | undefined;
                    value?: any;
                    externalValue?: string | undefined;
                } | {
                    $ref: string;
                    description?: string | undefined;
                    summary?: string | undefined;
                }> | undefined;
                schema?: Record<string, any> | undefined;
                style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                explode?: boolean | undefined;
                allowEmptyValue?: boolean | undefined;
                allowReserved?: boolean | undefined;
            })[] | undefined;
            requestBody?: {
                content: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }>;
                description?: string | undefined;
                required?: boolean | undefined;
                encoding?: Record<string, {
                    contentType: string;
                    headers?: Record<string, {
                        description?: string | undefined;
                        deprecated?: boolean | undefined;
                        content?: Record<string, {
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                        }> | undefined;
                        required?: boolean | undefined;
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                        style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                        explode?: boolean | undefined;
                    }> | undefined;
                }> | undefined;
            } | {
                $ref: string;
                description?: string | undefined;
                summary?: string | undefined;
            } | undefined;
            responses?: Record<string, {
                description: string;
                content?: Record<string, {
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    encoding?: Record<string, {
                        contentType: string;
                        headers?: Record<string, {
                            description?: string | undefined;
                            deprecated?: boolean | undefined;
                            content?: Record<string, {
                                example?: any;
                                examples?: Record<string, {
                                    description?: string | undefined;
                                    summary?: string | undefined;
                                    value?: any;
                                    externalValue?: string | undefined;
                                }> | undefined;
                                schema?: Record<string, any> | undefined;
                            }> | undefined;
                            required?: boolean | undefined;
                            example?: any;
                            examples?: Record<string, {
                                description?: string | undefined;
                                summary?: string | undefined;
                                value?: any;
                                externalValue?: string | undefined;
                            }> | undefined;
                            schema?: Record<string, any> | undefined;
                            style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                            explode?: boolean | undefined;
                        }> | undefined;
                    }> | undefined;
                }> | undefined;
                headers?: Record<string, {
                    description?: string | undefined;
                    deprecated?: boolean | undefined;
                    content?: Record<string, {
                        example?: any;
                        examples?: Record<string, {
                            description?: string | undefined;
                            summary?: string | undefined;
                            value?: any;
                            externalValue?: string | undefined;
                        }> | undefined;
                        schema?: Record<string, any> | undefined;
                    }> | undefined;
                    required?: boolean | undefined;
                    example?: any;
                    examples?: Record<string, {
                        description?: string | undefined;
                        summary?: string | undefined;
                        value?: any;
                        externalValue?: string | undefined;
                    }> | undefined;
                    schema?: Record<string, any> | undefined;
                    style?: "matrix" | "label" | "simple" | "form" | "spaceDelimited" | "pipeDelimited" | "deepObject" | undefined;
                    explode?: boolean | undefined;
                }> | undefined;
                links?: Record<string, {
                    description?: string | undefined;
                    operationId?: string | undefined;
                    parameters?: Record<string, string> | undefined;
                    requestBody?: string | undefined;
                    operationRef?: string | undefined;
                    server?: {
                        url: string;
                        description?: string | undefined;
                        variables?: Record<string, {
                            description?: string | undefined;
                            default?: string | undefined;
                            enum?: string[] | undefined;
                        }> | undefined;
                    } | undefined;
                }> | undefined;
            }> | undefined;
            deprecated?: boolean | undefined;
        } & {
            callbacks?: Record<string, z.infer<typeof ReferenceObjectSchema> | z.infer<typeof CallbackObjectSchema>>;
        }) | undefined;
    }> | undefined;
}>;
//# sourceMappingURL=components-object.d.ts.map